@@ -445,6 +445,7 @@ CREATE TABLE nsm_user (
     user_authid character varying(512),
     user_authkey character varying(64),
     user_email character varying(254) NOT NULL,
+    user_description character varying(255),
     user_disabled smallint DEFAULT 1 NOT NULL,
     user_created timestamp without time zone NOT NULL,
     user_modified timestamp without time zone NOT NULL
@@ -653,7 +654,7 @@ COPY cronk_principal_cronk (cpc_principal_id, cpc_cronk_id) FROM stdin;
 --
 
 COPY nsm_db_version (id, version, modified, created) FROM stdin;
-1	icinga-web/v1.8.0	2012-10-11 11:13:07	2012-10-11 11:13:07
+1	icinga-web/v1.8.3	2013-03-25 00:00:00	2013-03-23 00:00:00
 \.
 
 
@@ -970,6 +971,13 @@ CREATE INDEX pt_target_id_ix ON nsm_principal_target USING btree (pt_target_id);
 CREATE INDEX upref_search_key_idx ON nsm_user_preference USING btree (upref_key);
 
 
+--
+-- Name: upref_user_key_unique_idx; Type: INDEX; Schema: public; Owner: icinga_web; Tablespace: 
+--
+
+CREATE UNIQUE INDEX upref_user_key_unique_idx ON nsm_user_preference USING btree (upref_user_id, upref_key);
+
+
 --
 -- Name: user_name_unique; Type: INDEX; Schema: public; Owner: icinga_web; Tablespace: 
 --
@@ -1112,7 +1120,9 @@ ALTER TABLE ONLY nsm_user_role
     ADD CONSTRAINT nsm_user_role_usro_user_id_nsm_user_user_id FOREIGN KEY (usro_user_id) REFERENCES nsm_user(user_id) ON UPDATE CASCADE ON DELETE CASCADE;
 
 
---
+-- Unique key for nsm_target / target_name
+CREATE UNIQUE INDEX target_key_unique_target_name_idx ON nsm_target USING btree (target_name);
+
 -- Name: public; Type: ACL; Schema: -; Owner: postgres
 --
 
